##  Step 3: Verify Sync and View Discovered Items
  1. To verify the sync completed successfully, go to the Sync Log and look for entries that mention “Cloud ALM Flow API.”
![Log Message dialog showing a successful SAP Cloud ALM integration sync.](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio47daf5646e8343d7a2acdec20451e818_LowRes.png)
  2. In the SAP Discovery Inbox, go to Inventory > SAP Discovery.
  3. To view the discovered flow items, select Discovered Flow in the Classification filter.
The page displays items that list integration flows between systems.
